==> igniteui-angular-charts-18.2.0.tgz: package/esm5/lib/SeriesSelectionHighlightingManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HighlightingManager } from "igniteui-angular-core";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var SeriesSelectionHighlightingManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SeriesSelectionHighlightingManager, _super);
    function SeriesSelectionHighlightingManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SeriesSelectionHighlightingManager.prototype.isCrossContextHighlight = function (a) {
        var b = a;
        if (b.cp == 3 || b.cp == 4) {
            return true;
        }
        return false;
    };
    SeriesSelectionHighlightingManager.prototype.isContextValid = function (a) {
        var b = a;
        return b != null && b.db != null;
    };
    SeriesSelectionHighlightingManager.$t = markType(SeriesSelectionHighlightingManager, 'SeriesSelectionHighlightingManager', HighlightingManager.$);
    return SeriesSelectionHighlightingManager;
}(HighlightingManager));
export { SeriesSelectionHighlightingManager };

==> igniteui-angular-charts-20.0.0.tgz: package/esm5/lib/SeriesSelectionHighlightingManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HighlightingManager } from "igniteui-angular-core";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var SeriesSelectionHighlightingManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SeriesSelectionHighlightingManager, _super);
    function SeriesSelectionHighlightingManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SeriesSelectionHighlightingManager.prototype.isCrossContextHighlight = function (a) {
        var b = a;
        if (b.cq == 3 || b.cq == 4) {
            return true;
        }
        return false;
    };
    SeriesSelectionHighlightingManager.prototype.isContextValid = function (a) {
        var b = a;
        return b != null && b.dc != null;
    };
    SeriesSelectionHighlightingManager.$t = markType(SeriesSelectionHighlightingManager, 'SeriesSelectionHighlightingManager', HighlightingManager.$);
    return SeriesSelectionHighlightingManager;
}(HighlightingManager));
export { SeriesSelectionHighlightingManager };
